@@ -361,14 +361,18 @@ class Media(object):
         now = time.time()
         tmstps = []
         if schedule:
-            # os.remove(self.filepath)                                                                                                                                    
+            """
+                les fichiers media programmés
+                ne sont pas objet à suppression
+            """
             for key, tmstp in schedule.items():
                 t = [j for j in tmstp if j >= now]
                 tmstps += t
             tmstps = sorted(list(set(tmstps)))
 
             if not tmstp:
-                os.remove(self.filepath)
+                # je dois verifier ulterieurement
+                # l'usage de ce code
                 for redis_zset_key, infos in schedule.items():
                     timestamps = sorted(infos)
                     p = program.Program(
@@ -376,11 +380,13 @@ class Media(object):
                          ).infos(timestamps[0])
                     factor = 0
                     for timestamp, path in p.items():
-                        # à chaque fois qu'on rencontre une occurence du fichier                                                                                          
-                        # on décrémente le facteur de multiplication de 1                                                                                                 
-                        # pour que l'heure de début du programme                                                                                                          
-                        # venant après ladite occurence                                                                                                                   
-                        # soit réduite de la bonne valeur                                                                                                                 
+                        """
+                        à chaque fois qu'on rencontre une occurence du fichier
+                        on décrémente le facteur de multiplication de 1
+                        pour que l'heure de début du programme
+                        venant après ladite occurence
+                        soit réduite de la bonne valeur
+                        """
                         if timestamp in timestamps:
                             factor -= 1
                             PROGRAMS.zrem(redis_zset_key, path)
@@ -392,6 +398,9 @@ class Media(object):
                                 )
             else:
                 raise ValueError('Cannot delete for it is scheduled')
+        elif schedule == {}:
+            print("j'efface: {}".format(self.filepath))
+            os.remove(self.filepath)
         return
 
 
